@@ -1,5 +1,5 @@
 package Net::Async::Ping::ICMP;
-$Net::Async::Ping::ICMP::VERSION = '0.004000';
+$Net::Async::Ping::ICMP::VERSION = '0.004001';
 use Moo;
 use warnings NONFATAL => 'all';
 
@@ -160,7 +160,7 @@ sub _parse_icmp_packet {
             # 8 byte is the length of the ICMP Destination
             # unreachable header
             raw => substr($recv_msg, $offset + 8)
-        );
+        )->unpack;
         # skip if contained packet isn't an icmp packet
         return
             if $ipv4->protocol != NF_IPv4_PROTOCOL_ICMPv4;
@@ -349,7 +349,7 @@ Net::Async::Ping::ICMP
 
 =head1 VERSION
 
-version 0.004000
+version 0.004001
 
 =head1 DESCRIPTION
 
